@@ -3,11 +3,10 @@
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
 
+from collections import defaultdict
 import datetime
 import functools
 import random
-
-from collections import defaultdict
 from typing import (
     Any,
     Dict,
@@ -22,18 +21,13 @@ from typing import (
     Union,
 )
 
-from swh.model.model import (
-    Content,
-    SkippedContent,
-    Sha1Git,
-)
-
+from swh.model.model import Content, Sha1Git, SkippedContent
 from swh.storage.cassandra import CassandraStorage
 from swh.storage.cassandra.model import (
     BaseRow,
     ContentRow,
-    DirectoryRow,
     DirectoryEntryRow,
+    DirectoryRow,
     MetadataAuthorityRow,
     MetadataFetcherRow,
     ObjectCountRow,
@@ -42,11 +36,11 @@ from swh.storage.cassandra.model import (
     OriginVisitStatusRow,
     RawExtrinsicMetadataRow,
     ReleaseRow,
-    RevisionRow,
     RevisionParentRow,
+    RevisionRow,
     SkippedContentRow,
-    SnapshotRow,
     SnapshotBranchRow,
+    SnapshotRow,
 )
 from swh.storage.interface import ListOrder
 from swh.storage.objstorage import ObjStorage
@@ -54,7 +48,6 @@ from swh.storage.objstorage import ObjStorage
 from .common import origin_url_to_sha1
 from .writer import JournalWriter
 
-
 TRow = TypeVar("TRow", bound=BaseRow)
 
 
@@ -256,6 +249,9 @@ class InMemoryCqlRunner:
         primary_key = self._skipped_contents.primary_key_from_dict(content_hashes)
         return self._skipped_contents.get_from_primary_key(primary_key)
 
+    def skipped_content_get_from_token(self, token: int) -> Iterable[SkippedContentRow]:
+        return self._skipped_contents.get_from_token(token)
+
     ##########################
     # 'skipped_content_by_*' tables
     ##########################
@@ -265,6 +261,11 @@ class InMemoryCqlRunner:
     ) -> None:
         self._skipped_content_indexes[algo][content.get_hash(algo)].add(token)
 
+    def skipped_content_get_tokens_from_single_hash(
+        self, algo: str, hash_: bytes
+    ) -> Iterable[int]:
+        return self._skipped_content_indexes[algo][hash_]
+
     ##########################
     # 'directory' table
     ##########################
