@@ -4,16 +4,20 @@
 # See top-level LICENSE file for more information
 
 import datetime
+import logging
 import random
 import select
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 
 from swh.core.db import BaseDb
-from swh.core.db.db_utils import stored_procedure, jsonize as _jsonize
 from swh.core.db.db_utils import execute_values_generator
-from swh.model.model import OriginVisit, OriginVisitStatus, SHA1_SIZE
+from swh.core.db.db_utils import jsonize as _jsonize
+from swh.core.db.db_utils import stored_procedure
+from swh.model.model import SHA1_SIZE, OriginVisit, OriginVisitStatus
 from swh.storage.interface import ListOrder
 
+logger = logging.getLogger(__name__)
+
 
 def jsonize(d):
     return _jsonize(dict(d) if d is not None else None)
@@ -24,7 +28,7 @@ class Db(BaseDb):
 
     """
 
-    current_version = 161
+    current_version = 163
 
     def mktemp_dir_entry(self, entry_type, cur=None):
         self._cursor(cur).execute(
@@ -1339,4 +1343,12 @@ class Db(BaseDb):
             return dict(zip(self.dbversion_cols, cur.fetchone()))
 
     def check_dbversion(self):
-        return self.dbversion()["version"] == self.current_version
+        dbversion = self.dbversion()["version"]
+        if dbversion != self.current_version:
+            logger.warning(
+                "database dbversion (%s) != %s current_version (%s)",
+                dbversion,
+                __name__,
+                self.current_version,
+            )
+        return dbversion == self.current_version
