@@ -4,65 +4,55 @@
 # See top-level LICENSE file for more information
 
 import base64
+from collections import defaultdict
 import contextlib
+from contextlib import contextmanager
 import datetime
 import itertools
-
-from collections import defaultdict
-from contextlib import contextmanager
-from typing import (
-    Any,
-    Counter,
-    Dict,
-    Iterable,
-    List,
-    Optional,
-    Tuple,
-    Union,
-)
+from typing import Any, Counter, Dict, Iterable, List, Optional, Tuple, Union
 
 import attr
 import psycopg2
-import psycopg2.pool
 import psycopg2.errors
+import psycopg2.pool
 
-from swh.core.api.serializers import msgpack_loads, msgpack_dumps
-from swh.core.db.common import db_transaction_generator, db_transaction
+from swh.core.api.serializers import msgpack_dumps, msgpack_loads
+from swh.core.db.common import db_transaction, db_transaction_generator
+from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_bytes, hash_to_hex
 from swh.model.identifiers import SWHID
 from swh.model.model import (
+    SHA1_SIZE,
     Content,
     Directory,
-    Origin,
-    OriginVisit,
-    OriginVisitStatus,
-    Revision,
-    Release,
-    SkippedContent,
-    Sha1,
-    Sha1Git,
-    Snapshot,
-    SnapshotBranch,
-    TargetType,
-    SHA1_SIZE,
     MetadataAuthority,
     MetadataAuthorityType,
     MetadataFetcher,
     MetadataTargetType,
+    Origin,
+    OriginVisit,
+    OriginVisitStatus,
     RawExtrinsicMetadata,
+    Release,
+    Revision,
+    Sha1,
+    Sha1Git,
+    SkippedContent,
+    Snapshot,
+    SnapshotBranch,
+    TargetType,
 )
-from swh.model.hashutil import DEFAULT_ALGORITHMS, hash_to_bytes, hash_to_hex
-from swh.storage.exc import StorageArgumentException, StorageDBError, HashCollision
+from swh.storage.exc import HashCollision, StorageArgumentException, StorageDBError
 from swh.storage.interface import (
+    VISIT_STATUSES,
     ListOrder,
     PagedResult,
     PartialBranches,
-    VISIT_STATUSES,
 )
-from swh.storage.metrics import timed, send_metric, process_metrics
+from swh.storage.metrics import process_metrics, send_metric, timed
 from swh.storage.objstorage import ObjStorage
 from swh.storage.utils import (
-    get_partition_bounds_bytes,
     extract_collision_hash,
+    get_partition_bounds_bytes,
     map_optional,
     now,
 )
@@ -71,7 +61,6 @@ from swh.storage.writer import JournalWriter
 from . import converters
 from .db import Db
 
-
 # Max block size of contents to return
 BULK_BLOCK_CONTENT_LEN_MAX = 10000
 
@@ -1208,8 +1197,9 @@ class Storage:
     def origin_add(self, origins: List[Origin], db=None, cur=None) -> Dict[str, int]:
         urls = [o.url for o in origins]
         known_origins = set(url for (url,) in db.origin_get_by_url(urls, cur))
-        # use lists here to keep origins sorted; some tests depend on this
-        to_add = [url for url in urls if url not in known_origins]
+        # keep only one occurrence of each given origin while keeping the list
+        # sorted as originally given
+        to_add = sorted(set(urls) - known_origins, key=urls.index)
 
         self.journal_writer.origin_add([Origin(url=url) for url in to_add])
         added = 0
