@@ -7,14 +7,7 @@
 from typing import Dict, Iterable, List
 
 from swh.model.hashutil import MultiHash, hash_to_bytes, hash_to_hex
-from swh.model.model import (
-    Content,
-    Directory,
-    Release,
-    Revision,
-    Snapshot,
-)
-
+from swh.model.model import Content, Directory, Release, Revision, Snapshot
 from swh.storage import get_storage
 from swh.storage.exc import StorageArgumentException
 from swh.storage.interface import StorageInterface
